package com.qryord.project.master.field.service;

import com.qryord.project.master.field.domain.MField;

import java.util.List;

/**
 * 字段Service接口
 * 
 * @author ruoyi
 * @date 2022-08-06
 */
public interface IMFieldService 
{
    /**
     * 查询字段
     * 
     * @param id 字段主键
     * @return 字段
     */
    public MField selectMFieldById(Long id);

    /**
     * 查询字段列表
     * 
     * @param mField 字段
     * @return 字段集合
     */
    public List<MField> selectMFieldList(MField mField);

    /**
     * 新增字段
     * 
     * @param mField 字段
     * @return 结果
     */
    public int insertMField(MField mField);

    /**
     * 修改字段
     * 
     * @param mField 字段
     * @return 结果
     */
    public int updateMField(MField mField);

    /**
     * 批量删除字段
     * 
     * @param ids 需要删除的字段主键集合
     * @return 结果
     */
    public int deleteMFieldByIds(String ids);

    /**
     * 删除字段信息
     * 
     * @param id 字段主键
     * @return 结果
     */
    public int deleteMFieldById(Long id);

    /**
     * 字段拖动排序
     * @param mField
     * @return
     */
    int dragSorted(MField mField);
}
